Attribute VB_Name = "PhVintDigInp"
Option Explicit

   ' ========================================================================
   ' PhidgetDigitalInput  DAQ1200  (4 digital inputs)
   '
   ' The Digital Input class is used to monitor the state of Phidget digital
   ' inputs.  Use digital inputs to monitor the state of buttons, switches,
   ' or switch-to-ground sensors.

   ' ========================================================================
   ' PhidgetDigitalInput_create(
   '     PhidgetDigitalInputHandle *ch
   ' )
   ' Parameters:
   '     ch: The channel handle
   ' Return: The Phidget return code
   '
   ' Creates an instance of a Phidget channel.  Once created the channel may
   ' need to be configured to match the physical device and channel index you
   ' want to attach to, and then be opened by calling Phidget_open().  The
   ' Phidget channel handle must be released with PhidgetDigitalInput_delete().
   '
   Public Declare Function PhDigInpCreate& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalInput_create" ( _
      ByRef handle&)

   ' ========================================================================
   ' PhidgetDigitalInput_delete(
   '     PhidgetDigitalInputHandle *ch
   ' )
   ' Parameters:
   '     ch: The channel handle
   ' Return: The Phidget return code
   '
   ' Releases a Phidget channel handle created by PhidgetDigitalInput_create().
   ' If the channel is open when PhidgetDigitalInput_delete() is called, it
   ' will be closed.
   '
   Public Declare Function PhDigInpDelete& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalInput_delete" ( _
      ByRef handle&)

   ' ========================================================================
   ' PhidgetDigitalInput_getState(
   '     PhidgetDigitalInputHandle ch,
   '     int *state
   ' )
   ' Parameters:
   '     ch: The channel handle
   '     state: Pointer to the state value (16bit true false)
   ' Return: The Phidget return code
   '
   ' The most recent state value that the channel has reported.
   '
   Public Declare Function PhDigInpGetState& _
      Lib "Phidget22.dll" _
      Alias "PhidgetDigitalInput_getState" ( _
      ByVal handle&, _
      ByRef state&)

   ' ========================================================================
   ' PhidgetDigitalInput_setOnStateChangeHandler(
   '     PhidgetDigitalInputHandle ch,
   '     PhidgetDigitalInput_OnStateChangeCallback handler,
   '     void *ctxtr
   ' )
   ' Parameters:
   '     ch: The channel handle
   '     handler: The callback function
   '     ctx: User provided context pointer (userData)
   ' Return: The Phidget return code
   '
   ' This function requires PhDigInpOnStateChange& callback procedure
   ' handlerPtr& must be set to AddressOf PhDigInpOnStateChange
   '
   Public Declare Function PhDigInpSetOnStateChangeHandler& _
      Lib "Phidget22.dll" ( _
      ByVal handle&, _
      ByVal handlerPtr&, _
      ByVal userData&)


' ===========================================================================
' Event Callbacks, Subs, and Functions
' ===========================================================================

' ===========================================================================
Public Static Function PhDigInpOnStateChange&( _
   ByVal handle&, _
   ByVal userData&, _
   ByVal state&)
   ' This event will occur when the state of the digital input has changed.
   ' The state& value will either be 0 or 1 (true or false).
   ' vb true/false 1/0
   
   ' Sample code for startup:
   '     stat& = PhOnDigInpStateChange&(handle&, _
   '             AddressOf PhOnDigInpStateChange, state&)

   ' ========== User code HERE =========
   ' CAUTION: (Using CALLS here might cause .exe to crash)
   ' ===================================

   PhDigInpOnStateChange& = 0 ' Return Code
   
End Function

' ==========================================================================

' ==========================================================================
' PHIDGET Digital Input STARTUP
' ==========================================================================
Public Static Sub InitPhDigInp(indx&, stat&)
   ' Enter:    Dev(indx&)
   ' Return:   Dev(indx&).hndl&
   '           stat&  0=OK
   
   ' Create, configure, and open a Digital Input channel.
   ' stat& = 0 if the program exits successfully
   
   On Error Resume Next
   stat& = 0& ' Set default OK
   
   ' ===================================
   ' Create an instance of a Phidget channel.  Once created the
   ' channel may need to be configured to match the physical
   ' device and channel you want to attach to, and then be
   ' opened by calling Phidget_open().  The channel handle must
   ' be released with PhidgetDigitalInput_delete().
   '
   ' stat& (Error Code) will always be 0 if no Errors
   '
   stat& = PhDigInpCreate&(Dev(indx&).hndl) ' Create new handle
   If stat& <> 0 Then GoTo HandleErr
   
   ' SET SERIAL NUMBER
   stat& = PhSetDeviceSerialNumber(Dev(indx&).hndl, Dev(indx&).hubSn)
   If stat& <> 0 Then GoTo HandleErr

   ' SET ISHUB (0 if hub port is connected to a Phidget module)
   stat& = PhSetIsHubPortDevice(Dev(indx&).hndl, Dev(indx&).isHub)
   If stat& <> 0 Then GoTo HandleErr

   ' SET HUB PORT
   stat& = PhSetHubPort(Dev(indx&).hndl, Dev(indx&).port)
   If stat& <> 0 Then GoTo HandleErr

   ' SET CHANNEL
   stat& = PhSetChannel(Dev(indx&).hndl, Dev(indx&).ch)
   If stat& <> 0 Then GoTo HandleErr
   
   ' Setup the handlers to be run when the device is plugged in,
   ' opened from software, unplugged, closed from software, or
   ' generates an error.
   ' SETUP ATTACH EVENT
   stat& = PhSetOnAttach&(Dev(indx&).hndl, _
               AddressOf PhOnAttach, _
               indx&) ' returned with event for this handle
   If stat& <> 0 Then GoTo HandleErr

   ' SETUP DETACH EVENT
   stat& = PhSetOnDetach&(Dev(indx&).hndl, _
               AddressOf PhOnDetach, _
               indx&) ' returned with event for this handle
   If stat& <> 0 Then GoTo HandleErr

   ' SETUP ERROR EVENT
   ' Using common Error Handler for all phidget modules.
   stat& = PhSetOnError&(Dev(indx&).hndl, _
               AddressOf PhOnError, _
               indx&) ' returned with event for this handle
   If stat& <> 0 Then GoTo HandleErr

   ' SETUP OnStateChange handler
   stat& = PhDigInpSetOnStateChangeHandler(Dev(indx&).hndl, _
               AddressOf PhDigInpOnStateChange, _
               indx&) ' returned with event for this handle
   If stat& <> 0 Then GoTo HandleErr
   
   ' OPEN CHANNEL
   'stat& = PhOpen(Dev(indx&).hndl)
   
   ' OPEN CHANNEL & WAIT FOR ATTACH with timeout
   stat& = PhOpenWaitForAttachment(Dev(indx&).hndl, timeOutMs&)
   If stat& <> 0 Then GoTo HandleErr
   
   GoTo ExitSub
HandleErr:
   Call Form1.DisplayStatus(indx&, stat&, "InitPhDigInp")

ExitSub:

End Sub


